package cn.net.caoyao.cpzshandset.service.bll;

import java.util.List;

import android.content.Context;
import cn.net.caoyao.cpzshandset.bean.PackBean;
import cn.net.caoyao.cpzshandset.common.config.ConfigCreateService;
import cn.net.caoyao.cpzshandset.common.util.CacheGet;
import cn.net.caoyao.cpzshandset.db.presenter.PackDal;

public class PackBll{
	private PackDal dal;

	public PackBll(Context context) {
		ConfigCreateService service = new ConfigCreateService();
		dal = service.createPackDal(new CacheGet(), context);
	}

	/**
	 * 插入打包信息
	 * 
	 * @param packBean
	 * @return
	 */
	
	public int insertPack(PackBean packBean) {
		if (dal == null) {
			return -1;
		}
		return dal.insertPack(packBean);
	}
	/**
	 * 通过打包id，更新打包信息
	 * @param packBean
	 */
	public void updatePackById(PackBean packBean){
		if (dal == null) {
			return;
		}
		dal.updatePackById(packBean);
	}
	
	/**
	 * 通过打包id查询打包信息
	 * @param id
	 * @return
	 */
	public PackBean queryPackById(int id){
		if (dal == null) {
			return null;
		}
		return dal.queryPackById(id);
	}

	/**
	 * 查询所有的打包列表，降序排列
	 * @return
	 */
	
	public List<PackBean> queryAllPackList() {
		if (dal == null) {
			return null;
		}
		return dal.queryAllPackList();
	}
	/**
	 * 查询所有的打包列表，升序排列
	 * @return
	 */
	
	public List<PackBean> queryAllPackListASC() {
		if (dal == null) {
			return null;
		}
		return dal.queryAllPackListASC();
	}

	

	/**
	 * 通过打包id，删除打包信息
	 */
	
	public void deletePackInfoById(PackBean b) {
		if (dal == null) {
			return;
		}
		dal.deletePackInfoById(b);
	}

	/**
	 * 修改打包信息的状态
	 * @param status
	 * @param errorCode
	 * @param id
	 */
	
	public void updatePackStatusById(int status, int errorCode, int id) {
		if (dal == null) {
			return;
		}
		dal.updatePackStatusById(status, errorCode, id);
	}

	/**
	 * 已经作为包标签存在
	 * @param packBean
	 * @param labelId
	 * @return
	 */
	
	public boolean isPackageId(String labelId) {
		if (dal == null) {
			return false;
		}
		return dal.isPackageId(labelId);
	}

}
